Installation — Modoboa 1.7.4 documentation

### Navigation

- index
- next |
- previous |
- Modoboa 1.7.4 documentation »

# Installation

## Recommended way

If you start from scratch and want to deploy a complete mail server, you will love the modoboa installer! It is the easiest and the quickest way to setup a fully functional server (modoboa, postfix, dovecot, amavis and more) on one machine.

Warning

For now, only Debian and CentOS based Linux distributions are supported. We do our best to improve compatibility but if you use another Linux or a UNIX system, you will have to install Modoboa manually.

To use it, just run the following commands in your terminal:

    > git clone https://github.com/modoboa/modoboa-installer
    > cd modoboa-installer
    > sudo ./run.py <your domain>

Wait a few minutes and you’re done o/

## Manual installation

For those who need a manual installation or who just want to setup a specific part, here are the steps you must follow:

- Modoboa
- Web server
- Dovecot
- Postfix

### Extensions

Only few commands are needed to add a new extension to your setup.

In case you use a dedicated user and/or a virtualenv, do not forget to use them:

    > sudo -u <modoboa_user> -i
    > source <virtuenv_path>/bin/activate

Then, run the following commands:

    > pip install <EXTENSION>==<VERSION>
    > cd <modoboa_instance_dir>
    > python manage.py migrate
    > python manage.py collectstatic

Then, restart your web sever.

### Navigation

- index
- next |
- previous |
- Modoboa 1.7.4 documentation »